import { AUTH_ACTION_TYPES } from "../actions/types"
import { IChangeAttributes, IChangePassword, IConfirmSignUp, 
  IForgotPassword, IForgotPasswordSubmit, IResendConfirmationCode, ISignIn, ISignOut, ISignUp, 
  ISignUpSuccessful, ISignInSuccessful
} from '../actions/interfaces'


interface IAuthState {
  email: string;
  password: string;
  firstName: string;
  lastName: string;  

  isAuthenticated: boolean;
}

const AuthState: IAuthState = {
  email: '',
  password: '',
  firstName: '',
  lastName: '',

  isAuthenticated: false,
}

type IAction =  IChangeAttributes | IChangePassword | IConfirmSignUp | IForgotPassword | 
                IForgotPasswordSubmit | IResendConfirmationCode | ISignIn | ISignOut | ISignUp |
                ISignUpSuccessful | ISignInSuccessful 

export default (state: IAuthState = AuthState, action: IAction) => {
  switch (action.type) {

    case AUTH_ACTION_TYPES.SIGN_UP: {
      const { email, password, firstName, lastName } = action
      return {
        ...state,
        email,
        password,
        firstName,
        lastName,
      }
    }

    case AUTH_ACTION_TYPES.SIGN_IN: {
      const { email } = action
      return {
        ...state,
        email
      }
    }

    case AUTH_ACTION_TYPES.SIGN_IN_SUCCESSFUL: {
      return {
        ...AuthState,

        isAuthenticated: true,
      }
    }

    case AUTH_ACTION_TYPES.SIGN_OUT: {
      return {
        ...AuthState,

        isAuthenticated: false,
      }
    }

    case AUTH_ACTION_TYPES.FORGOT_PASSWORD: {
      const { email } = action
      return {
        ...state,
        email
      }
    }
    

    default: {
      return state
    }
  }
}